"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.lsk = void 0;
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const sodium_browserify_tweetnacl_1 = __importDefault(require("sodium-browserify-tweetnacl"));
const pbkdf2_1 = __importDefault(require("pbkdf2"));
const encryptor_1 = require("../helpers/encryptor");
const LiskHashSettings = {
    SALT: 'adm',
    ITERATIONS: 2048,
    KEYLEN: 32,
    DIGEST: 'sha256',
};
const network = {
    name: 'Lisk',
    port: 8000,
    wsPort: 8001,
    unit: 'LSK',
};
exports.lsk = {
    keys: (passphrase) => {
        const liskSeed = pbkdf2_1.default.pbkdf2Sync(passphrase, LiskHashSettings.SALT, LiskHashSettings.ITERATIONS, LiskHashSettings.KEYLEN, LiskHashSettings.DIGEST);
        const keyPair = sodium_browserify_tweetnacl_1.default.crypto_sign_seed_keypair(liskSeed);
        const address = lisk_cryptography_1.address.getLisk32AddressFromPublicKey(keyPair.publicKey);
        const addressHexBinary = lisk_cryptography_1.address.getAddressFromPublicKey(keyPair.publicKey);
        const addressHex = (0, encryptor_1.bytesToHex)(addressHexBinary);
        const privateKey = keyPair.secretKey.toString('hex');
        return {
            network,
            keyPair,
            address,
            addressHexBinary,
            addressHex,
            privateKey,
        };
    },
};
