import { Logger } from './logger';
import { GetNodeStatusResponseDto } from '../api/generated';
import { WebSocketClient, WsOptions } from './wsClient';
export interface NodeManagerOptions {
    nodes: string[];
    timeout?: number;
    socket?: WebSocketClient;
    checkHealthAtStartup?: boolean;
}
export interface ActiveNode {
    node: string;
    ping: number;
    baseURL: string;
    ip?: string;
    isHttps: boolean;
    height: number;
    heightEpsilon: number;
    socketSupport: boolean;
    wsPort: number;
    outOfSync?: boolean;
}
export declare class NodeManager {
    options: NodeManagerOptions;
    node: string;
    socket?: WebSocketClient;
    protected logger: Logger;
    private onReadyCallback?;
    private initialized;
    private isCheckingNodes;
    constructor(logger: Logger, options: NodeManagerOptions);
    onReady(callback: () => void): void;
    initSocket(options: WebSocketClient | WsOptions): void;
    private ready;
    updateNodes(isPlannedUpdate?: boolean): Promise<void>;
    chooseNode(activeNodes: ActiveNode[], forceChangeActiveNode?: boolean): Promise<void>;
    checkNode(node: string): Promise<(Omit<GetNodeStatusResponseDto, "success"> & {
        success: true;
    }) | {
        success: false;
    }>;
    checkNodes(): Promise<ActiveNode[]>;
}
