/// <reference types="node" />
import { MessageType } from '../constants';
import { KeyPair } from '../keys';
export interface BasicTransaction {
    timestamp: number;
    amount: number;
    senderPublicKey: string;
    senderId: string;
    asset: {};
}
export interface SendTransaction extends BasicTransaction {
    type: 0;
    recipientId: string;
    amount: number;
    asset: {};
}
export interface StateTransaction extends BasicTransaction {
    type: 9;
    recipientId: null;
    asset: {
        state: {
            key: string;
            value: string;
            type: 0;
        };
    };
}
export interface ChatTransaction extends BasicTransaction {
    type: 8;
    recipientId: string;
    amount: number;
    asset: {
        chat: {
            message: string;
            own_message: string;
            type: MessageType;
        };
    };
}
export interface DelegateTransaction extends BasicTransaction {
    type: 2;
    recipientId: null;
    asset: {
        delegate: {
            username: string;
            publicKey: string;
        };
    };
}
export interface VoteTransaction extends BasicTransaction {
    type: 3;
    asset: {
        votes: string[];
    };
}
export type SomeTransaction = VoteTransaction | DelegateTransaction | ChatTransaction | StateTransaction | SendTransaction;
export type PossiblySignedTransaction = SomeTransaction & {
    signature?: string;
};
export type SignedTransaction = SomeTransaction & {
    signature: string;
};
export declare function getHash(trs: PossiblySignedTransaction, options?: {
    skipSignature: boolean;
}): Buffer;
export declare function getAssetBytes(transaction: PossiblySignedTransaction): {
    assetBytes: Buffer | null;
    assetSize: number;
};
export declare function getBytes(transaction: PossiblySignedTransaction, skipSignature?: boolean): Buffer;
export declare function signTransaction(trs: SomeTransaction, keypair: KeyPair): string;
export declare function voteGetBytes(trs: VoteTransaction): Buffer | null;
export declare function delegatesGetBytes(trs: DelegateTransaction): Buffer | null;
export declare function statesGetBytes(trs: StateTransaction): Buffer | null;
export declare function chatGetBytes(trs: ChatTransaction): Buffer;
export declare function sign(hash: Buffer, keypair: KeyPair): Buffer;
