import { MessageType, TransactionType } from '../constants';
import type { KeyPair } from '../keys';
import type { AdamantAddress } from '../../api';
export type AnyTransactionData = (SendTransactionData | ChatTransactionData | VoteTransactionData | DelegateTransactionData | StateTransactionData) & {
    transactionType: TransactionType;
};
export interface BasicTransactionData {
    keyPair: KeyPair;
}
export interface SendTransactionData extends BasicTransactionData {
    recipientId: string;
    amount: number;
}
export interface ChatTransactionData extends BasicTransactionData {
    recipientId: AdamantAddress;
    message_type: MessageType;
    amount?: number;
    message: string;
    own_message: string;
}
export interface VoteTransactionData extends BasicTransactionData {
    votes: string[];
}
export interface DelegateTransactionData extends BasicTransactionData {
    username: string;
}
export interface StateTransactionData extends BasicTransactionData {
    key: string;
    value: string;
}
interface BasicTransaction<T extends TransactionType> {
    type: T;
    timestamp: number;
    amount: number;
    senderPublicKey: string;
    senderId: AdamantAddress;
    asset: {};
}
export declare const createBasicTransaction: <T extends TransactionType>(data: AnyTransactionData) => BasicTransaction<T>;
export declare const createSendTransaction: (data: SendTransactionData) => {
    signature: string;
    recipientId: string;
    amount: number;
    asset: {};
    type: TransactionType.SEND;
    timestamp: number;
    senderPublicKey: string;
    senderId: AdamantAddress;
};
export declare const createStateTransaction: (data: StateTransactionData) => {
    signature: string;
    recipientId: null;
    asset: {
        state: {
            key: string;
            value: string;
            type: 0;
        };
    };
    type: TransactionType.STATE;
    timestamp: number;
    amount: number;
    senderPublicKey: string;
    senderId: AdamantAddress;
};
export declare const createChatTransaction: (data: ChatTransactionData) => {
    signature: string;
    recipientId: `U${string}`;
    amount: number;
    asset: {
        chat: {
            message: string;
            own_message: string;
            type: MessageType;
        };
    };
    type: TransactionType.CHAT_MESSAGE;
    timestamp: number;
    senderPublicKey: string;
    senderId: AdamantAddress;
};
export declare const createDelegateTransaction: (data: DelegateTransactionData) => {
    signature: string;
    recipientId: null;
    asset: {
        delegate: {
            username: string;
            publicKey: string;
        };
    };
    type: TransactionType.DELEGATE;
    timestamp: number;
    amount: number;
    senderPublicKey: string;
    senderId: AdamantAddress;
};
export declare const createVoteTransaction: (data: VoteTransactionData) => {
    signature: string;
    recipientId: `U${string}`;
    asset: {
        votes: string[];
    };
    type: TransactionType.VOTE;
    timestamp: number;
    amount: number;
    senderPublicKey: string;
    senderId: AdamantAddress;
};
export * from './hash';
export * from './id';
