"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createVoteTransaction = exports.createDelegateTransaction = exports.createChatTransaction = exports.createStateTransaction = exports.createSendTransaction = exports.createBasicTransaction = void 0;
const hash_1 = require("./hash");
const keys_1 = require("../keys");
const time_1 = require("../time");
const constants_1 = require("../constants");
const createBasicTransaction = (data) => {
    const transaction = {
        type: data.transactionType,
        timestamp: (0, time_1.getEpochTime)(),
        amount: 0,
        senderPublicKey: data.keyPair.publicKey.toString('hex'),
        senderId: (0, keys_1.createAddressFromPublicKey)(data.keyPair.publicKey),
        asset: {},
    };
    return transaction;
};
exports.createBasicTransaction = createBasicTransaction;
const createSendTransaction = (data) => {
    const details = {
        ...data,
        transactionType: constants_1.TransactionType.SEND,
    };
    const transaction = {
        ...(0, exports.createBasicTransaction)(details),
        recipientId: details.recipientId,
        amount: details.amount,
        asset: {},
    };
    const signature = (0, hash_1.signTransaction)(transaction, details.keyPair);
    return {
        ...transaction,
        signature,
    };
};
exports.createSendTransaction = createSendTransaction;
const createStateTransaction = (data) => {
    const details = {
        ...data,
        transactionType: constants_1.TransactionType.STATE,
    };
    const transaction = {
        ...(0, exports.createBasicTransaction)(details),
        recipientId: null,
        asset: {
            state: {
                key: details.key,
                value: details.value,
                type: 0,
            },
        },
    };
    const signature = (0, hash_1.signTransaction)(transaction, details.keyPair);
    return {
        ...transaction,
        signature,
    };
};
exports.createStateTransaction = createStateTransaction;
const createChatTransaction = (data) => {
    const details = {
        ...data,
        transactionType: constants_1.TransactionType.CHAT_MESSAGE,
    };
    const transaction = {
        ...(0, exports.createBasicTransaction)(details),
        recipientId: details.recipientId,
        amount: details.amount || 0,
        asset: {
            chat: {
                message: data.message,
                own_message: data.own_message,
                type: data.message_type,
            },
        },
    };
    const signature = (0, hash_1.signTransaction)(transaction, details.keyPair);
    return {
        ...transaction,
        signature,
    };
};
exports.createChatTransaction = createChatTransaction;
const createDelegateTransaction = (data) => {
    const details = {
        ...data,
        transactionType: constants_1.TransactionType.DELEGATE,
    };
    const transaction = {
        ...(0, exports.createBasicTransaction)(details),
        recipientId: null,
        asset: {
            delegate: {
                username: details.username,
                publicKey: details.keyPair.publicKey.toString('hex'),
            },
        },
    };
    const signature = (0, hash_1.signTransaction)(transaction, details.keyPair);
    return {
        ...transaction,
        signature,
    };
};
exports.createDelegateTransaction = createDelegateTransaction;
const createVoteTransaction = (data) => {
    const details = {
        ...data,
        transactionType: constants_1.TransactionType.VOTE,
    };
    const basicTransaction = (0, exports.createBasicTransaction)(details);
    const transaction = {
        ...basicTransaction,
        recipientId: basicTransaction.senderId,
        asset: {
            votes: details.votes,
        },
    };
    const signature = (0, hash_1.signTransaction)(transaction, details.keyPair);
    return {
        ...transaction,
        signature,
    };
};
exports.createVoteTransaction = createVoteTransaction;
__exportStar(require("./hash"), exports);
__exportStar(require("./id"), exports);
